@@ -130,7 +130,10 @@ class RESTClient(RESTAssertion):
         :return:
         """
 
-        self.header = header or get_header_default()
+        try:
+            self.header = header.copy()
+        except AttributeError:
+            self.header = get_header_default()
 
         try:
             self.token = self.get_token()
@@ -181,7 +184,8 @@ class RESTClient(RESTAssertion):
             self.header = self.get_auth_header(header=custom_header)
         elif self.auth_basic:
             self.auth_basic = self._auth_basic()
-        elif custom_header:
+
+        if custom_header:
             self.header = custom_header
 
         # Make full url to use in request
@@ -261,9 +265,7 @@ class RESTClient(RESTAssertion):
             # For 'GET', 'HEAD' request
             else:
                 # For usual 'GET' without query params
-                header = custom_header if custom_header else self.header
-
-                logger.debug(f'Header={header}, '
+                logger.debug(f'Header={self.header}, '
                              f'Cookies={cookies}, '
                              f'Timeout={request_timeout}')
 
@@ -271,7 +273,7 @@ class RESTClient(RESTAssertion):
                                             url=link,
                                             auth=self.auth_basic,
                                             cookies=cookies,
-                                            headers=header,
+                                            headers=self.header,
                                             verify=verify,
                                             timeout=request_timeout)
 
